@@ -18,6 +18,7 @@
  */
 
 #include "arena.h"
+#include "granatier_random.h"
 
 #include <QPoint>
 #include <QDateTime>
@@ -91,19 +92,10 @@ void Arena::addPlayerPosition(const QPointF &p_position)
 {
     m_playerPosition.append(p_position);
 
-    //TODO: maybe in own function
     int nShuffle;
     for (int i = 0; i < m_playerPosition.size(); i++)
     {
-        nShuffle = m_playerPosition.size() * (qrand()/1.0)/RAND_MAX;
-        if(nShuffle >= m_playerPosition.size())
-        {
-            nShuffle = m_playerPosition.size() - 1;
-        }
-        else if(nShuffle < 0)
-        {
-            nShuffle = 0;
-        }
+        nShuffle = granatier::RNG::fromRange(0, m_playerPosition.size()-1);
         m_playerPosition.swap(i, nShuffle);
     }
 }
@@ -143,7 +135,7 @@ QPoint Arena::getCoords(Cell* p_cell) const
 
 int Arena::getRowFromY(const qreal p_y) const
 {
-    int nRow = (p_y / Granatier::CellSize);
+    int nRow = static_cast<int>(p_y / Granatier::CellSize);
     if (p_y < 0)
     {
         nRow -= 1;
@@ -153,7 +145,7 @@ int Arena::getRowFromY(const qreal p_y) const
 
 int Arena::getColFromX(const qreal p_x) const
 {
-    int nCol = (p_x / Granatier::CellSize);
+    int nCol = static_cast<int>(p_x / Granatier::CellSize);
     if (p_x < 0)
     {
         nCol -= 1;
